/****************************************************************************
** Meta object code from reading C++ file 'devicemanagerrealize.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../impl/networkmanager/devicemanagerrealize.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'devicemanagerrealize.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3dde7network20DeviceManagerRealizeE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::DeviceManagerRealize::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network20DeviceManagerRealizeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::DeviceManagerRealize",
        "onDeviceEnabledChanged",
        "",
        "QDBusObjectPath",
        "path",
        "enabled",
        "onConnectionAdded",
        "connectionUni",
        "onDeviceStateChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'onDeviceEnabledChanged'
        QtMocHelpers::SlotData<void(QDBusObjectPath, bool)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Slot 'onConnectionAdded'
        QtMocHelpers::SlotData<void(const QString &)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'onDeviceStateChanged'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DeviceManagerRealize, qt_meta_tag_ZN3dde7network20DeviceManagerRealizeE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::DeviceManagerRealize::staticMetaObject = { {
    QMetaObject::SuperData::link<NetworkDeviceRealize::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network20DeviceManagerRealizeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network20DeviceManagerRealizeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network20DeviceManagerRealizeE_t>.metaTypes,
    nullptr
} };

void dde::network::DeviceManagerRealize::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeviceManagerRealize *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onDeviceEnabledChanged((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: _t->onConnectionAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->onDeviceStateChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        }
    }
}

const QMetaObject *dde::network::DeviceManagerRealize::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::DeviceManagerRealize::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network20DeviceManagerRealizeE_t>.strings))
        return static_cast<void*>(this);
    return NetworkDeviceRealize::qt_metacast(_clname);
}

int dde::network::DeviceManagerRealize::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetworkDeviceRealize::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN3dde7network25WiredDeviceManagerRealizeE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::WiredDeviceManagerRealize::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network25WiredDeviceManagerRealizeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::WiredDeviceManagerRealize"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WiredDeviceManagerRealize, qt_meta_tag_ZN3dde7network25WiredDeviceManagerRealizeE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::WiredDeviceManagerRealize::staticMetaObject = { {
    QMetaObject::SuperData::link<DeviceManagerRealize::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network25WiredDeviceManagerRealizeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network25WiredDeviceManagerRealizeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network25WiredDeviceManagerRealizeE_t>.metaTypes,
    nullptr
} };

void dde::network::WiredDeviceManagerRealize::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WiredDeviceManagerRealize *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dde::network::WiredDeviceManagerRealize::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::WiredDeviceManagerRealize::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network25WiredDeviceManagerRealizeE_t>.strings))
        return static_cast<void*>(this);
    return DeviceManagerRealize::qt_metacast(_clname);
}

int dde::network::WiredDeviceManagerRealize::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DeviceManagerRealize::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3dde7network28WirelessDeviceManagerRealizeE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::WirelessDeviceManagerRealize::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network28WirelessDeviceManagerRealizeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::WirelessDeviceManagerRealize",
        "onNetworkAppeared",
        "",
        "ssid",
        "onNetworkDisappeared",
        "onInterfaceFlagsChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'onNetworkAppeared'
        QtMocHelpers::SlotData<void(const QString &)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'onNetworkDisappeared'
        QtMocHelpers::SlotData<void(const QString &)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'onInterfaceFlagsChanged'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WirelessDeviceManagerRealize, qt_meta_tag_ZN3dde7network28WirelessDeviceManagerRealizeE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::WirelessDeviceManagerRealize::staticMetaObject = { {
    QMetaObject::SuperData::link<DeviceManagerRealize::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network28WirelessDeviceManagerRealizeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network28WirelessDeviceManagerRealizeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network28WirelessDeviceManagerRealizeE_t>.metaTypes,
    nullptr
} };

void dde::network::WirelessDeviceManagerRealize::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WirelessDeviceManagerRealize *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onNetworkAppeared((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->onNetworkDisappeared((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->onInterfaceFlagsChanged(); break;
        default: ;
        }
    }
}

const QMetaObject *dde::network::WirelessDeviceManagerRealize::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::WirelessDeviceManagerRealize::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network28WirelessDeviceManagerRealizeE_t>.strings))
        return static_cast<void*>(this);
    return DeviceManagerRealize::qt_metacast(_clname);
}

int dde::network::WirelessDeviceManagerRealize::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DeviceManagerRealize::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}
QT_WARNING_POP
